package jp.co.intra_mart.sample.workflow.purchase.listener;

import static jp.co.intra_mart.foundation.contentssearch.model.field.Fields.STRING;
import static jp.co.intra_mart.foundation.contentssearch.web.common.Constants.TREE_FACET_SEPARATOR;
import static jp.co.intra_mart.foundation.contentssearch.workflow.common.Constants.IMW_DOCUMENT_TYPE;
import jp.co.intra_mart.foundation.contentssearch.exception.ContentsSearchCrawlingException;
import jp.co.intra_mart.foundation.contentssearch.model.content.InputContent;
import jp.co.intra_mart.foundation.contentssearch.workflow.crawler.listener.WorkflowMatterCrawlingAddListener;
import jp.co.intra_mart.framework.base.event.EventException;
import jp.co.intra_mart.framework.base.event.EventManager;
import jp.co.intra_mart.framework.base.event.EventManagerException;
import jp.co.intra_mart.framework.base.event.EventPropertyException;
import jp.co.intra_mart.framework.system.exception.ApplicationException;
import jp.co.intra_mart.framework.system.exception.SystemException;
import jp.co.intra_mart.sample.workflow.purchase.model.event.SelectEvent;
import jp.co.intra_mart.sample.workflow.purchase.model.event.SelectEventResult;

/**
 * サンプル 物品購買用 クローラ登録文書追加リスナー
 * @author INTRAMART
 */
public class WorkflowItemDataCrawlingAddListner implements WorkflowMatterCrawlingAddListener {

    @Override
    public void addInputContent(final InputContent inputContent, final String systemMatterId, final String userDataId) throws ContentsSearchCrawlingException {
        EventManager eventManager;
        try {
            // １．引数のパラメータ情報を元に、アプリケーションデータを取得する。
            eventManager = EventManager.getEventManager();
            final SelectEvent selectEvent = (SelectEvent) eventManager.createEvent("imw_sample_purchase", "select");
            selectEvent.setUserDataId(userDataId);
            final SelectEventResult eventResult = (SelectEventResult) eventManager.dispatch(selectEvent, true);
            // ２．アプリケーションデータを登録情報に追加するか判定を行う。
            if (eventResult.getModelObject() == null) {
                return;
            }
            final String itemName = eventResult.getModelObject().getItemName();
            if (itemName == null) {
                return;
            }
            // ３．引数の文書登録用オブジェクトにアプリケーションデータを追加する。
            // ３－１．テキストフィールドに品名を追加
            inputContent.addText(itemName);
            // ３－２．動的フィールドに品名を追加
            inputContent.addValue(STRING.toField("item_name_string"), itemName);
            // ３－３．文書種別の追加（静的ファセット）
            inputContent.addType(IMW_DOCUMENT_TYPE + TREE_FACET_SEPARATOR + "purchase"); // "workflow$purchase"
        } catch (final EventManagerException e) {
            throw new ContentsSearchCrawlingException(e);
        } catch (final EventPropertyException e) {
            throw new ContentsSearchCrawlingException(e);
        } catch (final EventException e) {
            throw new ContentsSearchCrawlingException(e);
        } catch (final SystemException e) {
            throw new ContentsSearchCrawlingException(e);
        } catch (final ApplicationException e) {
            throw new ContentsSearchCrawlingException(e);
        }
    }

}
